<?php
/**
 * This class manages all functionality with our Capture theme.
 */
class Capture {
	/**
	 * @var string
	 */
	public $version = '1.1.6';

	private static $instance; // Keep track of the instance

	/**
	 * @var EDD_SL_Theme_Updater, Instance of the EDD Software Licensing Theme Updater class
	 */
	protected $_updater;

	/**
	 * Function used to create instance of class.
	 */
	public static function instance() {
		if ( ! isset( self::$instance ) )
			self::$instance = new Capture;

		return self::$instance;
	}


	/**
	 * This function sets up all of the actions and filters on instance
	 */
	function __construct() {
		add_action( 'after_switch_theme', array( $this, 'after_switch_theme' ) ); // Flush rewrite rules on activation
		add_action( 'after_setup_theme', array( $this, 'after_setup_theme' ), 20 ); // Register image sizes
		add_action( 'widgets_init', array( $this, 'widgets_init' ), 20 ); // Unregister sidebars and alter Primary Sidebar output
		add_action( 'pre_get_posts', array( $this, 'pre_get_posts' ) ); // Used to enqueue editor styles based on post type
		add_action( 'wp_enqueue_scripts', array( $this, 'wp_enqueue_scripts' ) ); // Enqueue all stylesheets (Main Stylesheet, Fonts, etc...)
		add_action( 'the_post', array( $this, 'the_post' ) ); // Remove Default Jetpack Share Buttons
		add_filter( 'the_content', array( $this, 'the_content' ) ); // Prepend Jetpack Share Buttons
		add_filter( 'post_gallery', array( $this, 'post_gallery' ), 10, 2 ); // Modify default WordPress gallery shortcode output
		add_action( 'wp_footer', array( $this, 'wp_footer' ) ); // Responsive navigation functionality
		add_action( 'do_meta_boxes', array( $this, 'do_meta_boxes' ) ); // Remove default Featured Image meta box
		add_filter( 'admin_post_thumbnail_html', array( $this, 'admin_post_thumbnail_html' ), 10, 2 ); // Add Featured Video Meta
		add_action( 'save_post', array( $this, 'save_post' ) ); // Save Featured Video meta

		// Theme Customizer
		add_action( 'customize_register', array( $this, 'customize_register' ), 25 ); // Add settings/sections/controls to Theme Customizer
		add_filter( 'theme_mod_primary_color', array( $this, 'theme_mod_primary_color' ) ); // Set the default primary color
		add_filter( 'theme_mod_secondary_color', array( $this, 'theme_mod_secondary_color' ) ); // Set the default secondary color
		add_filter( 'theme_mod_content_color', array( $this, 'theme_mod_content_color' ) ); // Set the default content color
		add_filter( 'theme_mod_link_color', array( $this, 'theme_mod_link_color' ) ); // Set the default link color

		// Capture Slideshow
		add_action( 'wp_ajax_capture_slideshow', array( $this, 'wp_ajax_capture_slideshow' ) ); // Ajax/Backbone Requests
		add_action( 'wp_ajax_nopriv_capture_slideshow', array( $this, 'wp_ajax_capture_slideshow' ) ); // Ajax/Backbone Requests
		add_action( 'init', array( $this, 'init' ) ); // URL Endpoint
		add_filter( 'request', array( $this, 'request' ) ); // Modify request for URL Endpoint (Above)

		// Capture Slideshow (WordPress Gallery)
		add_action( 'wp_ajax_capture_slideshow_gallery', array( $this, 'wp_ajax_capture_slideshow_gallery' ) ); // Ajax/Backbone Requests
		add_action( 'wp_ajax_nopriv_capture_slideshow_gallery', array( $this, 'wp_ajax_capture_slideshow_gallery' ) ); // Ajax/Backbone Requests
		
		// Capture Theme Hooks
		add_action( 'capture_post_footer_right', array( $this, 'capture_post_footer_right' ) ); // Output Jetpack Share Buttons

		// WooCommerce
		remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 ); // Remove default WooCommerce content wrapper
		remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 ); // Remove default WooCommerce content wrapper
		add_action( 'woocommerce_before_main_content', array( $this, 'woocommerce_before_main_content' ) ); // Add Capture WooCommerce content wrapper
		add_action( 'woocommerce_after_main_content', array( $this, 'woocommerce_after_main_content' ) ); // Add Capture WooCommerce content wrapper
		add_filter( 'woocommerce_product_settings', array( $this, 'woocommerce_product_settings' ) ); // Adjust default WooCommerce product settings
		add_filter( 'loop_shop_per_page', array( $this, 'loop_shop_per_page' ), 20 ); // Adjust number of items displayed on a catalog page
		remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 ); // Remove default WooCommerce related products
		add_action( 'woocommerce_after_single_product_summary', array( $this, 'woocommerce_after_single_product_summary' ), 20 ); // Add WooCommerce related products (3x3)

		// Theme Options
		add_filter( 'sds_theme_options_defaults', array( $this, 'sds_theme_options_defaults' ) ); // Add to default settings
		add_action( 'admin_init', array( $this, 'capture_admin_init' ), 99 ); // Add settings sections and fields
		add_filter( 'sanitize_option_sds_theme_options', array( $this, 'sanitize_option_sds_theme_options' ) ); // Sanitize added settings

		// Theme updates
		add_action( 'admin_init', array( $this, 'admin_init' ) ); // Check and handle updates for theme

		// Conductor
		add_filter( 'conductor_widget_featured_image_size', array( $this, 'conductor_widget_featured_image_size' ), 10, 2 ); // Adjust featured image size
		add_action( 'conductor_widget_output_before', array( $this, 'conductor_widget_output_before' ), 10, 2 ); // Content Wrapper Element ("tuck" effect)
		add_action( 'conductor_widget_output_after', array( $this, 'conductor_widget_output_after' ), 10, 2 ); // Content Wrapper Element ("tuck" effect)
		add_action( 'conductor_widget_author_byline_before', array( $this, 'conductor_widget_author_byline_before' ), 10, 2 ); // Post Author Wrapper Element
		add_action( 'conductor_widget_author_byline_after', array( $this, 'conductor_widget_author_byline_after' ), 10, 2 ); // Post Author Wrapper Element

		// Gravity Forms
		add_filter( 'gform_field_input', array( $this, 'gform_field_input' ), 10, 5 ); // Add placholder to newsletter form
		add_filter( 'gform_confirmation', array( $this, 'gform_confirmation' ), 10, 4 ); // Change confirmation message on newsletter form
	}


	/************************************************************************************
	 *    Functions to correspond with actions above (attempting to keep same order)    *
	 ************************************************************************************/

	/**
	 * This function flushes the rewrite rules to ensure the endpoint registered below functions properly.
	 */
	function after_switch_theme() {
		flush_rewrite_rules();
	}

	/**
	 * This function adds images sizes to WordPress.
	 */
	function after_setup_theme() {
		global $content_width;

		/**
		 * Set the Content Width for embedded items.
		 */
		if ( ! isset( $content_width ) )
			$content_width = 1106;

		add_image_size( 'capture-1200x500', 1200, 500, true ); // Used for featured images on blog page
		add_image_size( 'capture-1200x9999', 1200, 9999, false ); // Used for featured images on single posts

		// Remove top & footer navigation areas which are registered in SDS Core (Theme Options)
		unregister_nav_menu( 'top_nav' );
		unregister_nav_menu( 'footer_nav' );

		// WooCommerce Support
		add_theme_support( 'woocommerce' );

		// Change default core markup for search form, comment form, and comments, etc... to HTML5
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list'
		) );

		// Custom Background (color/image)
		add_theme_support( 'custom-background', array(
			'default-color' => '#ffffff'
		) );

		// Slocum Theme
		add_theme_support( 'slocum-theme', array(
			// Global
			'global' => array(
				// Fonts
				'fonts' => array(
					// Site Title
					'title' => array(
						'font_size' => 72,
						'font_family' => 'Damion',
						'css_selector' => '' // TODO: Required for specific elements but not for all
					),
					// Tagline
					'tagline' => array(
						'font_size' => 24,
						'font_family' => 'Open Sans',
						'css_selector' => ''
					),
					// Headings
					'headings' => array(
						'font_family' => 'Oswald',
						'css_selector' => ''
					),
					// Body (all other text)
					'body' => array(
						'font_size' => 16,
						'font_family' => 'Open Sans',
						'css_selector' => ''
					)
				)
			)
		) );

		// Theme textdomain
		load_theme_textdomain( 'capture', get_template_directory() . '/languages' );
	}

	/**
	 * This function unregisters extra sidebars that are not used in this theme. It also modifies
	 * the global $wp_registered_sidebars to change the output of the Primary Sidebar for the "tuck" effect (CSS).
	 */
	function widgets_init() {
		global $wp_registered_sidebars;

		// Primary Sidebar
		if ( isset( $wp_registered_sidebars['primary-sidebar'] ) ) {
			$wp_registered_sidebars['primary-sidebar']['before_widget'] .= '<section class="widget-container">';
			$wp_registered_sidebars['primary-sidebar']['after_widget'] .= '</section>';
		}

		// Unregister unused sidebars which are registered in SDS Core
		unregister_sidebar( 'front-page-slider-sidebar' );
		unregister_sidebar( 'front-page-sidebar' );
		unregister_sidebar( 'header-call-to-action-sidebar' );
		unregister_sidebar( 'secondary-sidebar' );
		unregister_sidebar( 'footer-sidebar' );
	}

	/**
	 * This function adds editor styles based on post type, before TinyMCE is initialized.
	 * It will also enqueue the correct color scheme stylesheet to better match front-end display.
	 */
	function pre_get_posts() {
		global $sds_theme_options, $post;

		$protocol = is_ssl() ? 'https' : 'http';

		// Admin only and if we have a post
		if ( is_admin() && ! empty( $post ) ) {
			add_editor_style( 'css/editor-style.css' );

			// Add correct color scheme if selected
			if ( function_exists( 'sds_color_schemes' ) && ! empty( $sds_theme_options['color_scheme'] ) && $sds_theme_options['color_scheme'] !== 'default' ) {
				$color_schemes = sds_color_schemes();
				add_editor_style( 'css/' . $color_schemes[$sds_theme_options['color_scheme']]['stylesheet'] );
			}

			// Open Sans & Oswald Web Fonts (include only if a web font is not selected in Theme Options)
			if ( ! function_exists( 'sds_web_fonts' ) || empty( $sds_theme_options['web_font'] ) )
				add_editor_style( $protocol . '://fonts.googleapis.com/css?family=Open+Sans|Oswald' ); // Google WebFonts (Open Sans & Oswald)
		}
	}


	/**
	 * This function enqueues all styles and scripts (Main Stylesheet, Fonts, etc...).
	 * Stylesheets can be conditionally included if needed
	 */
	function wp_enqueue_scripts() {
		global $sds_theme_options, $post;

		$is_mobile = wp_is_mobile(); // Determine if user is on a mobile device
		$protocol = is_ssl() ? 'https' : 'http'; // Determine current protocol

		// Capture (main stylesheet)
		wp_enqueue_style( 'capture', get_template_directory_uri() . '/style.css', false, $this->version );

		// Enqueue the child theme stylesheet only if a child theme is active
		if ( is_child_theme() )
			wp_enqueue_style( 'capture-child', get_stylesheet_uri(), array( 'capture' ), $this->version );

		// Damion, Open Sans & Oswald Web Fonts (include only if a web font is not selected in Theme Options)
		if ( ! function_exists( 'sds_web_fonts' ) || empty( $sds_theme_options['web_font'] ) )
			wp_enqueue_style( 'damion-open-sans-oswald-web-fonts', $protocol . '://fonts.googleapis.com/css?family=Damion|Open+Sans|Oswald', false, $this->version ); // Google WebFonts (Damion, Open Sans & Oswald)

		// Font Awesome
		wp_enqueue_style( 'font-awesome-css-min', get_template_directory_uri() . '/includes/css/font-awesome.min.css' );

		// Ensure jQuery is loaded on the front end for our footer script (@see wp_footer() below)
		wp_enqueue_script( 'jquery' );

		// If we're not on a single attachment page
		if ( ! is_attachment() ) {
			// ImagesLoaded
			wp_enqueue_script( 'imagesloaded-min', get_template_directory_uri() . '/js/imagesloaded.min.js', array( 'jquery' ), $this->version, true );

			// Hammer
			if ( $is_mobile )
				wp_enqueue_script( 'hammer-min', get_template_directory_uri() . '/js/hammer.min.js', false, $this->version, true );

			// Capture Slideshow
			wp_enqueue_script( 'capture-slideshow-min', get_template_directory_uri() . '/js/capture-slideshow.min.js', ( $is_mobile ) ? array( 'jquery', 'backbone', 'hammer-min' ) : array( 'jquery', 'backbone' ), $this->version, true );
			wp_localize_script( 'capture-slideshow-min', 'capture', array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'nonce' => wp_create_nonce( 'capture_slideshow' ),
				'permalinks' => ( get_option( 'permalink_structure' ) ) ? true : false,
				'is_archive' => ( is_archive() || is_home() || is_search() ) ? true : false,
				'is_mobile' => ( $is_mobile ) ? true : false
			) );
		}

		// FitVids
		wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/fitvids.js', array( 'jquery' ), $this->version );
	}

	/**
	 * This function removes the default Jetpack Share Buttons output on single posts and
	 * posts shown on the home, archive, and search page templates.
	 */
	function the_post( $post ) {
		if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'sharedaddy' ) && $post->post_type === 'post' && ( is_single() || is_home() || is_archive() || is_search() ) ) {
			remove_filter( 'the_content', 'sharing_display', 19 );
			remove_filter( 'the_excerpt', 'sharing_display', 19 );
		}
	}

	/**
	 * This function prepends Jetpack Share Buttons to single post content.
	 */
	function the_content( $content ) {
		if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'sharedaddy' ) && is_single() )
			$content = sharing_display() . $content;

		return $content;
	}

	/**
	 * This function modifies the default output of the WordPress gallery shortcode. It uses the same
	 * functionality, with various changes in the output HTML for the Capture Slideshow.
	 *
	 * @link http://core.trac.wordpress.org/browser/tags/3.5.1/wp-includes/media.php#L658 (original function)
	 */
	function post_gallery( $output, $attr ) {
		$post = get_post();
		$post_id = $post ? $post->ID : 0;

		static $instance = 0;
		$instance++;

		if ( ! empty( $attr['ids'] ) ) {
			// 'ids' is explicitly ordered, unless you specify otherwise.
			if ( empty( $attr['orderby'] ) )
				$attr['orderby'] = 'post__in';
			$attr['include'] = $attr['ids'];
		}
		// We're trusting author input, so let's at least make sure it looks like a valid orderby statement
		if ( isset( $attr['orderby'] ) ) {
			$attr['orderby'] = sanitize_sql_orderby( $attr['orderby'] );
			if ( ! $attr['orderby'] )
				unset( $attr['orderby'] );
		}

		extract( shortcode_atts( array(
			'order'      => 'ASC',
			'orderby'    => 'menu_order ID',
			'id'         => $post ? $post->ID : 0,
			'itemtag'    => 'dl',
			'icontag'    => 'dt',
			'captiontag' => 'dd',
			'columns'    => 3,
			'size'       => 'thumbnail',
			'include'    => '',
			'exclude'    => '',
			'link'       => ''
		), $attr, 'gallery') );

		$id = intval($id);
		if ( 'RAND' == $order )
			$orderby = 'none';

		if ( ! empty( $include ) ) {
			$_attachments = get_posts( array( 'include' => $include, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby ) );

			$attachments = array();
			foreach ( $_attachments as $key => $val ) {
				$attachments[$val->ID] = $_attachments[$key];
			}
		} elseif ( ! empty( $exclude ) ) {
			$attachments = get_children( array( 'post_parent' => $id, 'exclude' => $exclude, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby ) );
		} else {
			$attachments = get_children( array( 'post_parent' => $id, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby ) );
		}

		if ( empty( $attachments ) )
			return '';

		if ( is_feed() ) {
			$output = "\n";
			foreach ( $attachments as $att_id => $attachment )
				$output .= wp_get_attachment_link( $att_id, $size, true ) . "\n";
			return $output;
		}

		$itemtag = tag_escape( $itemtag );
		$captiontag = tag_escape( $captiontag );
		$icontag = tag_escape( $icontag );
		$valid_tags = wp_kses_allowed_html( 'post' );
		if ( ! isset( $valid_tags[ $itemtag ] ) )
			$itemtag = 'dl';
		if ( ! isset( $valid_tags[ $captiontag ] ) )
			$captiontag = 'dd';
		if ( ! isset( $valid_tags[ $icontag ] ) )
			$icontag = 'dt';

		$columns = intval( $columns );
		$itemwidth = $columns > 0 ? floor( 100/$columns ) : 100;
		$float = is_rtl() ? 'right' : 'left';

		$selector = "gallery-{$instance}";

		$gallery_style = $gallery_div = '';
		if ( apply_filters( 'use_default_gallery_style', true ) )
			$gallery_style = "
			<style type='text/css'>
			#{$selector} {
			margin: auto;
			}
			#{$selector} .gallery-item {
			float: {$float};
			margin-top: 10px;
			text-align: center;
			width: {$itemwidth}%;
			}
			#{$selector} img {
			border: 2px solid #cfcfcf;
			}
			#{$selector} .gallery-caption {
			margin-left: 0;
			}
			/* see gallery_shortcode() in wp-includes/media.php */
			</style>";
		$size_class = sanitize_html_class( $size );
		$gallery_div = "<div id='$selector' class='gallery galleryid-{$id} gallery-columns-{$columns} gallery-size-{$size_class}'>";
		$output = apply_filters( 'gallery_style', $gallery_style . "\n\t\t" . $gallery_div );

		$i = 0;
		foreach ( $attachments as $id => $attachment ) {
			// Add slideshow overlay to $image_output
			if ( ! empty( $link ) && 'file' === $link ) {
				$image_link = wp_get_attachment_url( $id );
				$image_source = wp_get_attachment_image( $id, $size );
				
				$image_output = "<a class='capture-slideshow-link' href='{$image_link}'>
					<!--[if gt IE 8]><!-->
						<section class='slideshow-overlay'>
							<svg xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' version='1.1' x='0px' y='0px' width='102.222px' height='67.146px' viewBox='0.857 16.177 102.222 67.146' enable-background='new 0.857 16.177 102.222 67.146' xml:space='preserve'><g><path fill='#FFFFFF' d='M20.08 83.323h63.663V16.177H20.08V83.323z M24.576 22.357h54.785v54.786H24.576V22.357z'/><rect x='94.466' y='21.722' fill='#FFFFFF' width='4.676' height='52.753'/><rect x='84.993' y='18.369' fill='#FFFFFF' width='8.248' height='61.942'/><rect x='100.382' y='25.393' fill='#FFFFFF' width='2.697' height='45.412'/><rect x='4.795' y='21.722' fill='#FFFFFF' width='4.677' height='52.753'/><rect x='10.696' y='18.369' fill='#FFFFFF' width='8.248' height='61.942'/><rect x='0.857' y='25.393' fill='#FFFFFF' width='2.698' height='45.412'/></g><g><path fill='#FFFFFF' d='M31.696 29.477V46.1l7.124-7.125l7.124 7.125l2.376-2.375l-7.124-7.124l7.124-7.125H31.696z'/><path fill='#FFFFFF' d='M72.241 29.477v16.421l-7.036-7.037l-7.037 7.037l-2.347-2.346l7.037-7.037l-7.037-7.038H72.241z'/><path fill='#FFFFFF' d='M31.696 70.024V53.6l7.038 7.04l7.037-7.04l2.346 2.35l-7.038 7.037l7.038 7.037H31.696z'/><path fill='#FFFFFF' d='M72.241 70.024V53.6l-7.036 7.04l-7.037-7.04l-2.347 2.35l7.037 7.034l-7.037 7.04H72.241z'/></g></svg>
						</section>
					<!--<![endif]-->
					{$image_source}
				</a>";
			}
			elseif ( ! empty( $link ) && 'none' === $link )
				$image_output = wp_get_attachment_image( $id, $size, false );
			else
				$image_output = wp_get_attachment_link( $id, $size, true, false );

			$image_meta  = wp_get_attachment_metadata( $id );

			$orientation = '';
			if ( isset( $image_meta['height'], $image_meta['width'] ) )
				$orientation = ( $image_meta['height'] > $image_meta['width'] ) ? 'portrait' : 'landscape';

			$output .= ( ! empty( $link ) && 'file' === $link ) ? "<{$itemtag} class='gallery-item capture-slideshow-gallery-item'>" : "<{$itemtag} class='gallery-item'>";
			$output .= "
			<{$icontag} class='gallery-icon {$orientation}' data-gallery-id='{$instance}' data-gallery-image-id='{$id}' data-post-id='{$post_id}'>
				$image_output
			</{$icontag}>";
			if ( $captiontag && trim($attachment->post_excerpt) ) {
				$output .= "
				<{$captiontag} class='wp-caption-text gallery-caption'>
				" . wptexturize($attachment->post_excerpt) . "
				</{$captiontag}>";
			}
			$output .= "</{$itemtag}>";
			if ( $columns > 0 && ++$i % $columns == 0 )
				$output .= '<br style="clear: both" />';
		}

		$output .= "
		<br style='clear: both;' />
		</div>\n";

		return $output;
	}

	/**
	 * This function outputs the necessary Javascript for the responsive menus and Capture Slideshow.
	 */
	function wp_footer() {
		global $post;
	?>
		<script type="text/javascript">
			// <![CDATA[
				jQuery( function( $ ) {
					// Mobile Nav & Social Media
					$( '.mobile-nav-button' ).on( 'touch click', function ( e ) {
						e.stopPropagation();
						$( '.mobile-nav-button, .mobile-nav, body' ).toggleClass( 'open' );
					} );

					$( '.mobile-nav-close-button' ).on( 'touch click', function ( e ) {
						e.stopPropagation();
						$( '.mobile-nav-button, .mobile-nav, body' ).removeClass( 'open' );
					} );

					$( '.social-media-button' ).on( 'touch click', function( e ) {
						e.stopPropagation();
						$( 'body > .social' ).toggleClass( 'open' );
					} );

					$( document ).on( 'touch click', function() {
						$( '.mobile-nav-button, .mobile-nav, body, body > .social' ).removeClass( 'open' );
					} );

					// Capture Slideshow (Gallery)
					$( 'a.capture-slideshow-link', '.gallery' ).click( function( e ) {
						var $this = $( this );
						e.preventDefault();

						$( '#capture-slideshow' ).captureSlideshow( {
							gallery: true,
							gallery_id: ( parseInt( $this.parent().attr( 'data-gallery-id' ), 10 ) - 1 ),
							gallery_image_id: parseInt( $this.parent().attr( 'data-gallery-image-id' ), 10 ),
							current_post_id: parseInt( $this.parent().attr( 'data-post-id' ), 10 ),
							gallery_thumbs: $( '.capture-slideshow-gallery-item', '#' + $this.parents( '.post' ).attr( 'id' ) ),
						} ); 
					} );

					<?php if ( is_single() && has_post_thumbnail() ) : // Single Posts with Featured Images ?>
						$( '.post-image-full-link', '.post' ).click( function( e ) {
							e.preventDefault();

							$( '#capture-slideshow' ).captureSlideshow(); // Capture Slideshow
						} );
					<?php endif; ?>

					// Featured Videos
					if ( $( '.featured-video' ).length ) {
						$( '.featured-video' ).fitVids( {
							callback: function( video ) {
								$this = $( video );
								// Fade in video and fade out loader container
								$this.fadeIn( 250 ).parents( '.featured-video' ).addClass( 'loaded' ).find( '.loader-container' ).addClass( 'hide' );
							}
						} );
					}

					// All other videos in the post
					$( '.post-container, .widget' ).fitVids();
				} );

				<?php if ( is_single() && has_post_thumbnail() && get_query_var( 'lightbox' ) ) : // Determine if the request contains lightbox query and enable slideshow if so ?>
					// Window Load
					jQuery( window ).load( function() {
						// Document Ready
						jQuery( function() {
							jQuery( '#capture-slideshow' ).captureSlideshow( {
								lightbox: true
							} );
						} );
					} );
				<?php endif; ?>
			// ]]>
		</script>
	<?php

		// Mobile menu styling for logged in users with the admin bar
		if ( is_admin_bar_showing() ) :
	?>
			<style type="text/css">
				.top-bar, .mobile-menu {
					top: 46px;
				}
			</style>
	<?php
		endif;
	}

	/**
	 * This function removes the default Featured Image meta box which will be re-initialized in the following function.
	 */
	function do_meta_boxes() {
		global $post;

		// All post types that support post thumbnails
		if ( ! empty( $post ) &&  post_type_supports( $post->post_type, 'thumbnail' ) ) {
			remove_meta_box( 'postimagediv', null, 'side' ); // Remove meta box from all post types
			add_meta_box( 'postimagediv', __( 'Featured Image or Featured Video', 'capture' ), 'post_thumbnail_meta_box', null, 'side', 'low' );
		}
	}

	/**
	 * This function adds a Featured Video URL field to the Featured Image meta box.
	 */
	function admin_post_thumbnail_html( $content, $post_id ) {
		$video_url = get_post_meta( $post_id, '_capture_video_url', true );

		$content .= '<hr style="width: 100%; height: 1px; background: #ccc; border: none; display: inline-block;" />';
		$content .= '<label for="_capture_video_url" style="padding-bottom: 6px; display: block;"><strong>' .__( 'Featured Video URL:', 'capture' ) . '</strong></label>';
		$content .= wp_nonce_field( 'set_capture_post_video_' . $post_id, 'set_capture_post_video_' . $post_id, false, false );
		$content .= '<input type="text" name="_capture_video_url" id="_capture_video_url" class="widefat capture-video-id" placeholder="Enter a URL here" autocomplete="off" value="' . esc_url( $video_url ) . '" />';
		$content .= '<small style="padding: 6px 0 10px; color: #888; display: block;"><em>Enter a URL above to display a featured video. You may use any of the video services that are currently <a href="http://codex.wordpress.org/Embeds#Okay.2C_So_What_Sites_Can_I_Embed_From.3F" target="_blank">supported by WordPress</a>.</em></small>';

		return $content;
	}

	/**
	 * This function handles saving the custom post meta from the Featured Video meta box.
	 */
	function save_post( $post_id ) {
		// Auto-saving, doing ajax, or bulk edit, proceed as normal
		if ( wp_is_post_revision( $post_id ) || ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) || ( defined( 'DOING_AJAX' ) && DOING_AJAX ) || isset( $_REQUEST['bulk_edit'] ) )
			return;

		// Featured Video
		if ( isset( $_POST['set_capture_post_video_' . $post_id] ) && wp_verify_nonce( $_POST['set_capture_post_video_' . $post_id], 'set_capture_post_video_' . $post_id ) && ! empty( $_POST['_capture_video_url'] ) )
			update_post_meta( $post_id, '_capture_video_url', esc_url( $_POST['_capture_video_url'] ) );
		else
			delete_post_meta( $post_id, '_capture_video_url' );
	}


	/********************
	 * Theme Customizer *
	 ********************/

	/**
	 * This function registers various Theme Customizer options for this theme.
	 *
	 * It also sets background-color and background-image settings in Theme Customizer to use
	 * the refresh method instead of postMessage.
	 *
	 * Theme Functions priorities:
	 * - primary_color = 10
	 * - secondary_color = 15
	 * - content_color = 20
	 * - background_color = 30
	 */
	function customize_register( $wp_customize ) {
		// Custom background color/image "refresh" method
		if ( get_theme_support( 'custom-background', 'wp-head-callback' ) === '_custom_background_cb' ) {
			foreach ( array( 'color', 'image' ) as $prop ) {
				$wp_customize->get_setting( 'background_' . $prop )->transport = 'refresh';
			}
		}
	}

	/**
	 * This function sets the default primary color in the Theme Customizer.
	 */
	function theme_mod_primary_color( $color ) {
		// Return the current color if set
		if ( $color )
			return $color;

		// Return the selected color scheme content color if set
		if ( ( $selected_color_scheme = sds_get_color_scheme( false ) ) && isset( $selected_color_scheme['primary_color'] ) )
			return $selected_color_scheme['primary_color'];

		// Return nothing if we don't have a color at this point
		return '';
	}

	/**
	 * This function sets the default secondary color in the Theme Customizer.
	 */
	function theme_mod_secondary_color( $color ) {
		// Return the current color if set
		if ( $color )
			return $color;

		// Return the selected color scheme content color if set
		if ( ( $selected_color_scheme = sds_get_color_scheme( false ) ) && isset( $selected_color_scheme['secondary_color'] ) )
			return $selected_color_scheme['secondary_color'];

		// Return nothing if we don't have a color at this point
		return '';
	}
	/**
	 * This function sets the default color for the content area in the Theme Customizer.
	 */
	function theme_mod_content_color( $color ) {
		// Return the current color if set
		if ( $color )
			return $color;

		// Return the selected color scheme content color if set
		if ( ( $selected_color_scheme = sds_get_color_scheme( false ) ) && isset( $selected_color_scheme['content_color'] ) )
			return $selected_color_scheme['content_color'];

		// Return nothing if we don't have a color at this point
		return '';
	}

	/**
	 * This function sets the default color for links found in the content area in the Theme Customizer.
	 */
	function theme_mod_link_color( $color ) {
		// Return the current color if set
		if ( $color )
			return $color;

		// Return the selected color scheme link color if set
		if ( ( $selected_color_scheme = sds_get_color_scheme( false ) ) && isset( $selected_color_scheme['link_color'] ) )
			return $selected_color_scheme['link_color'];

		// Return the selected color scheme primary color if set
		if ( ( $selected_color_scheme = sds_get_color_scheme( false ) ) && isset( $selected_color_scheme['primary_color'] ) )
			return $selected_color_scheme['primary_color'];

		// Return nothing if we don't have a color at this point
		return '';
	}


	/**
	 * This function handles Ajax/Backbone requests for the Capture Slideshow
	 */
	function wp_ajax_capture_slideshow() {
		global $wpdb;

		// Make sure we have a valid request
		check_ajax_referer( 'capture_slideshow', 'nonce' );

		// Determine protocol
		$protocol = is_ssl() ? 'https' : 'http';

		// Select two previous, the current, and two next posts with featured images
		$current_post_id = ( isset( $_REQUEST['current_post_id'] ) ) ? abs( ( int ) $_REQUEST['current_post_id'] ) : false;
		$initial_post_id = ( isset( $_REQUEST['initial_post_id'] ) ) ? abs( ( int ) $_REQUEST['initial_post_id'] ) : false;
		$num_next_prev_posts = ( isset( $_REQUEST['num_next_prev_posts'] ) && ( int ) $_REQUEST['num_next_prev_posts'] <= 5 ) ? abs( ( int ) $_REQUEST['num_next_prev_posts'] ) : 2;

		if ( $current_post_id && $initial_post_id && $num_next_prev_posts ) {
			$capture_slideshow_posts = $wpdb->get_results( "( SELECT ID, post_title, post_date FROM $wpdb->posts INNER JOIN $wpdb->postmeta ON ( $wpdb->posts.ID = $wpdb->postmeta.post_id ) WHERE post_date < ( SELECT post_date FROM $wpdb->posts WHERE ID = $current_post_id ) AND ( $wpdb->posts.post_type = 'post' ) AND ( $wpdb->posts.post_status = 'publish' ) AND ( $wpdb->postmeta.meta_key = '_thumbnail_id' ) GROUP BY $wpdb->posts.ID ORDER BY post_date DESC LIMIT $num_next_prev_posts ) UNION ( SELECT ID, post_title, post_date FROM $wpdb->posts INNER JOIN $wpdb->postmeta ON ( $wpdb->posts.ID = $wpdb->postmeta.post_id ) WHERE ID = $current_post_id OR post_date > ( SELECT post_date AS current_post_date FROM $wpdb->posts WHERE ID = $current_post_id ) AND ( $wpdb->posts.post_type = 'post' ) AND ( $wpdb->posts.post_status = 'publish' ) AND ( $wpdb->postmeta.meta_key = '_thumbnail_id' ) GROUP BY $wpdb->posts.ID ORDER BY post_date LIMIT " . ( $num_next_prev_posts + 1 ) . " )" );

			// Build Backbone Models (if we have posts)
			if ( ! empty( $capture_slideshow_posts ) && is_array( $capture_slideshow_posts ) ) {
				$models = array();
				$current_image_index = 0;

				// Ensure we have an array ordered by post date DESC
				usort( $capture_slideshow_posts, array( $this, 'sort_post_date_desc' ) );

				foreach( $capture_slideshow_posts as $post ) {
					$featured_image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );

					// Capture Slideshow Model
					$model = array(
						'img' => array(
							'src' => $featured_image[0],
							'width' => $featured_image[1],
							'height' => $featured_image[2]
						),
						'post' => array(
							'id' => $post->ID,
							'title' => $post->post_title,
							'date' => sprintf( __( 'Posted On %1$s', 'capture' ) , get_the_time( 'F jS, Y', $post->ID ) ),
							'timestamp' => strtotime( $post->post_date ),
							'permalink' => str_replace( $protocol . '://' . $_SERVER['SERVER_NAME'], '', get_permalink( $post->ID ) ) // Just return the URI
						),
					);

					// Append current post details to Capture Slideshow Model
					if ( ( int ) $post->ID === $current_post_id ) {
						$model['current_image'] = true;
						$current_image_index = count( $models );
					}

					// Append initial post details to Capture Slideshow Model
					if ( ( int ) $post->ID === $initial_post_id )
						$model['initial_image'] = true;

					$models[] = $model; // Append current model to model group
				}

				// Check to see if there are no more previous/next images
				if ( count( $models ) < ( $num_next_prev_posts * 2 + 1 ) ) {
					// No more previous images (current image is not in the middle)
					if ( $current_image_index < $num_next_prev_posts )
						$models[0]['no_more_images'] = true;

					// No more next images
					if( ( count( $models ) - $current_image_index - 1 ) < $num_next_prev_posts )
						$models[( count( $models ) - 1 )]['no_more_images'] = true;
				}

				// Check the database if necessary just to make sure
				if ( count( $models ) <= ( $num_next_prev_posts * 2 + 1 ) ) {
					if ( ! isset( $models[0]['no_more_images'] ) && ! ( $no_more_images = $wpdb->get_var( "SELECT COUNT(*) FROM $wpdb->posts INNER JOIN $wpdb->postmeta ON ( $wpdb->posts.ID = $wpdb->postmeta.post_id ) WHERE $wpdb->posts.post_date > ( SELECT post_date FROM $wpdb->posts WHERE ID = " . $models[0]['post']['id'] . " ) AND ( $wpdb->posts.post_type = 'post' ) AND ( $wpdb->posts.post_status = 'publish' ) AND ( $wpdb->postmeta.meta_key = '_thumbnail_id' )" ) ) )
						$models[0]['no_more_images'] = true;
					if ( ! isset( $models[( count( $models ) - 1 )]['no_more_images'] ) && ! ( $no_more_images = $wpdb->get_var( "SELECT COUNT(*) FROM $wpdb->posts INNER JOIN $wpdb->postmeta ON ( $wpdb->posts.ID = $wpdb->postmeta.post_id ) WHERE post_date < ( SELECT post_date FROM $wpdb->posts WHERE ID = " . $models[( count( $models ) - 1 )]['post']['id'] . " ) AND ( $wpdb->posts.post_type = 'post' ) AND ( $wpdb->posts.post_status = 'publish' ) AND ( $wpdb->postmeta.meta_key = '_thumbnail_id' )" ) ) )
						$models[( count( $models ) - 1 )]['no_more_images'] = true;
				}

				echo json_encode( $models ); // Return models to collection
			}
		}

		exit;
	}

	/**
	 * This function handles Ajax/Backbone requests for the Capture Slideshow for WordPress Galleries
	 */
	function wp_ajax_capture_slideshow_gallery() {
		global $wpdb;

		// Make sure we have a valid request
		check_ajax_referer( 'capture_slideshow', 'nonce' );

		// Determine protocol
		$protocol = is_ssl() ? 'https' : 'http';

		// Select two previous, the current, and two next posts with featured images
		$current_post_id = ( isset( $_REQUEST['current_post_id'] ) ) ? abs( ( int ) $_REQUEST['current_post_id'] ) : false;
		$gallery_id = ( isset( $_REQUEST['gallery_id'] ) ) ? abs( ( int ) $_REQUEST['gallery_id'] ) : false;
		$gallery_image_id = ( isset( $_REQUEST['gallery_image_id'] ) ) ? abs( ( int ) $_REQUEST['gallery_image_id'] ) : false;

		if ( $current_post_id && $gallery_id !== false && $gallery_image_id ) {
			$post = get_post( $current_post_id );

			// Validate the post
			if ( $post && ( $galleries = get_post_galleries( $post, false ) ) ) {
				$models = array();

				//Build Backbone Models (if we have images)
				foreach ( $galleries as $gallery ) {
					// Make sure the gallery links to the file (if not we're ignoring)
					if( isset( $gallery['link'] ) && $gallery['link'] === 'file' ) {
						$images = get_posts( array( 'post_type' => 'attachment', 'post_mime_type' => 'image', 'include' => explode( ',', $gallery['ids'] ), 'orderby' => 'post__in' ) );

						// Loop through images in gallery
						foreach( $images as $image ) {
							$image_src = wp_get_attachment_image_src( $image->ID, 'full' );

							// Capture Slideshow Model
							$model = array(
								'img' => array(
									'id' => $image->ID,
									'src' => $image_src[0],
									'width' => $image_src[1],
									'height' => $image_src[2]
								),
								'post' => array(
									'id' => $post->ID,
									'title' => $post->post_title,
									'date' => sprintf( __( 'Posted On %1$s', 'capture' ) , get_the_time( 'F jS, Y', $post->ID ) ),
									'timestamp' => strtotime( $post->post_date ),
									'permalink' => str_replace( $protocol . '://' . $_SERVER['SERVER_NAME'], '', get_permalink( $post->ID ) ) // Just return the URI
								),
							);

							// Append current/initial post details to Capture Slideshow Model
							if ( $image->ID === $gallery_image_id ) {
								$model['current_image'] = true;
								$model['initial_image'] = true;
							}

							$models[] = $model; // Append current model to model group
						}
					}
				}

				echo json_encode( $models ); // Return models to collection
			}
		}

		exit;
	}

	/**
	 * This function adds a URL Endpoint for the Capture Slideshow lightbox.
	 */
	function init() {
		add_rewrite_endpoint( 'lightbox', EP_PERMALINK ); // http://example.com/permalink/lightbox/
	}

	/**
	 * This function modifies the request to ensure the above URL Endpoint functions as we desire.
	 */
	 function request( $request ) {
		// Check to make sure our endpoint is set
		if( isset( $request['lightbox'] ) )
			$request['lightbox'] = true;

		return $request;
	}


	/***********************
	 * Capture Theme Hooks *
	 ***********************/

	/**
	 * This function outputs Jetpack Share Buttons in post footers.
	 */
	function capture_post_footer_right( $post ) {
		if( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'sharedaddy' ) && $post->post_type === 'post' )
			echo sharing_display();
	}


	/***************
	 * WooCommerce *
	 ***************/

	/**
	 * This function alters the default WooCommerce content wrapper starting element.
	 */
	function woocommerce_before_main_content(){
	?>
		<section class="woocommerce woo-commerce post">
			<section class="post-container">
				<article class="post-content cf">
	<?php
	}

	/**
	 * This function alters the default WooCommerce content wrapper ending element.
	 */
	function woocommerce_after_main_content(){
	?>
				</article>
			</section>
		</section>
	<?php
	}


	/**
	 * This function adjusts the default WooCommerce Product settings.
	 */
	function woocommerce_product_settings( $settings ) {
		if ( is_array( $settings ) )
			foreach( $settings as &$setting )
				// Adjust the default value of the Catalog image size
				if( $setting['id'] === 'shop_catalog_image_size' )
					$setting['default']['width'] = $setting['default']['height'] = 300;

		return $settings;
	}

	/**
	 * This function changes the number of products output on the Catalog page.
	 */
	function loop_shop_per_page( $num_items ) {
		return 12;
	}

	/**
	 * This function changes the number of related products displayed on a single product page.
	 */
	function woocommerce_after_single_product_summary() {
		woocommerce_related_products( array(
			'posts_per_page' => 3,
			'columns' => 3
		) );
	}


	/*****************
	 * Theme Options *
	 *****************/

	/**
	 * This function adds to the default Theme Options settings.
	 */
	function sds_theme_options_defaults( $defaults ) {
		// capture
		$defaults['capture'] = array();

		// Mobile Menu
		$defaults['capture']['mobile_menu'] = array();

		// Mobile Menu Sub-Pages
		$defaults['capture']['mobile_menu']['hide_sub_pages'] = false;

		return $defaults;
	}

	/**
	 * This function adds settings sections and fields specific to capture.
	 */
	function capture_admin_init() {
		add_settings_field( 'capture_show_mobile_menu_sub_pages_field', __( 'Show or Hide Sub-Pages:', 'capture' ), array( $this, 'capture_show_mobile_menu_sub_pages_field' ), 'sds-theme-options[general]', 'sds_theme_options_show_hide_elements_section' );
	}

	/**
	 * This function is the callback for the show/hide sub pages in mobile menu settings field.
	 */
	function capture_show_mobile_menu_sub_pages_field() {
		global $sds_theme_options;
	?>
		<div class="checkbox sds-theme-options-checkbox checkbox-show-hide checkbox-show-hide-sub-pages-mobile-menu" data-label-left="<?php esc_attr_e( 'Show', 'capture' ); ?>" data-label-right="<?php esc_attr_e( 'Hide', 'capture' ); ?>">
			<input type="checkbox" id="sds_theme_options_hide_sub_pages_mobile_menu" name="sds_theme_options[capture][mobile_menu][hide_sub_pages]" <?php ( isset( $sds_theme_options['capture']['mobile_menu']['hide_sub_pages'] ) ) ? checked( $sds_theme_options['capture']['mobile_menu']['hide_sub_pages'] ) : checked( false ); ?> />
			<label for="sds_theme_options_hide_sub_pages_mobile_menu">| | |</label>
		</div>
		<span class="description"><?php _e( 'When "show" is displayed, the sub-pages will be displayed in the mobile menu.', 'capture' ); ?></span>
	<?php
	}


	/**
	 * This function sanitizes/validates settings on the Theme Options panel.
	 */
	function sanitize_option_sds_theme_options( $input ) {
		// Mobile Menu Sub-Pages
		$input['capture']['mobile_menu']['hide_sub_pages'] = ( isset( $input['capture']['mobile_menu']['hide_sub_pages'] ) && $input['capture']['mobile_menu']['hide_sub_pages'] ) ? true : false;

		return $input;
	}


		/*****************
	 * Theme Updates *
	 *****************/

	/**
	 * This function handles theme updates from the ThemeUpdateChecker library. It will also
	 * flush rewrite rules upon theme activation for the URL endpoint (registered above).
	 */
	function admin_init() {
		global $pagenow;

		if ( ! class_exists( 'EDD_SL_Theme_Updater' ) )
			return;

		// Fetch current theme details
		$sds_theme_options_instance = SDS_Theme_Options_Instance();

		// Fetch the license
		$sds_theme_options = SDS_Theme_Options::get_sds_theme_options();

		// Create the updater
		$this->_updater = new EDD_SL_Theme_Updater( array(
				'remote_api_url' => SDS_Theme_Options::$update_url,
				'version' 	=> $this->version,
				'license' 	=> $sds_theme_options['license']['key'],
				'item_name' => $sds_theme_options_instance->theme->get( 'Name' ),
				'author' 	=> __( 'Slocum Studio', 'conductor' )
			)
		);

		// Ensure theme updates "work" on multisite (@see function descriptions below)
		if ( is_multisite() )
			$this->multisite_theme_update_check();

		// Flush rewrite rules only on activation (for URL Endpoint registered above)
		if ( is_admin() && isset( $_REQUEST['activated'] ) && $pagenow == 'themes.php' )
			flush_rewrite_rules();
	}


	/**
	 * This function ensures that multisite updates "work".
	 * It first checks to make sure the _maybe_update_themes() function exists (@see WP_INC/update.php as of 3.5.2).
	 * If the function does exist, use it to check for theme updates.
	 * If the function does not exist, use the one we've provided which is identical as of 3.5.2.
	 * "works" is in quotation marks because it requires the site that has this theme active to at least make one admin page request (i.e. loading the dashboard).
	 */
	function multisite_theme_update_check() {
		/* delete_site_transient('update_themes'); // Used for DEBUG */

		if ( function_exists( '_maybe_update_themes' ) )
			_maybe_update_themes();
		else
			$this->maybe_update_themes();
	}

	/**
	 * This function is identical to the one provided in WP 3.5.2 and will check to see if WP should check for theme updates.
	 * It is used as a fallback in multisite_theme_update_check above.
	 */
	function maybe_update_themes() {
		$current = get_site_transient( 'update_themes' );

		if ( ! defined( 'HOUR_IN_SECONDS' ) )
			define( HOUR_IN_SECONDS, 60 );

		if ( isset( $current->last_checked ) && 12 * HOUR_IN_SECONDS > ( time( ) - $current->last_checked ) )
			return;

		wp_update_themes();
	}


	/*************
	 * Conductor *
	 *************/

	/**
	 * This function adjusts the featured image size on Conductor widgets only if a size has not been selected by the user.
	 */
	// TODO:
	function conductor_widget_featured_image_size( $size, $instance ) {
		// Only adjust the size if a user has not selected one
		if ( isset( $instance['post_thumbnails_size'] ) && ! empty( $instance['post_thumbnails_size'] ) )
			return $instance['post_thumbnails_size'];

		// Large
		if ( isset( $instance['widget_size'] ) && $instance['widget_size'] === 'large' )
			$size = 'capture-1200x500';
		// Medium
		else if ( isset( $instance['widget_size'] ) && $instance['widget_size'] === 'medium' )
			$size = 'capture-1200x500';
		// Small
		else if ( isset( $instance['widget_size'] ) && $instance['widget_size'] === 'small' )
			$size = 'capture-1200x500';

		return $size;
	}

	/**
	 * This function outputs the opening content wrapper element for the "tuck" effect.
	 */
	function conductor_widget_output_before( $post, $instance ) {
	?>
		<div class="post-container">
	<?php
	}

	/**
	 * This function outputs the closing content wrapper element for the "tuck" effect.
	 */
	function conductor_widget_output_after( $post, $instance ) {
	?>
		</div>
	<?php
	}

	/**
	 * This function outputs the opening post author wrapper element for the date CSS to take effect.
	 */
	function conductor_widget_author_byline_before( $post, $instance ) {
	?>
		<div class="post-date">
	<?php
	}

	/**
	 * This function outputs the closing post author wrapper element for the date CSS to take effect.
	 */
	function conductor_widget_author_byline_after( $post, $instance ) {
	?>
		</div>
	<?php
	}


	/*****************
	 * Gravity Forms *
	 *****************/

	/**
	 * This function adds the HTML5 placeholder attribute to forms with a CSS class of the following:
	 * .mc-gravity, .mc_gravity, .mc-newsletter, .mc_newsletter classes
	 */
	function gform_field_input( $input, $field, $value, $lead_id, $form_id ) {
		$form_meta = RGFormsModel::get_form_meta( $form_id );
		$form_css_classes = explode( ' ', $form_meta['cssClass'] );

		// Ensure the current form has one of our supported classes and alter the field accordingly if we're not on admin
		if ( isset( $form['cssClass'] ) && ! is_admin() && in_array( $form_css_classes, array( 'mc-gravity', 'mc_gravity', 'mc-newsletter', 'mc_newsletter' ) ) )
			$input = '<div class="ginput_container"><input name="input_' . $field['id'] . '" id="input_' . $form_id . '_' . $field['id'] . '" type="text" value="" class="large" placeholder="' . $field['label'] . '" /></div>';

		return $input;
	}

	/**
	 * This function alters the confirmation message on forms with a CSS class of the following:
	 * .mc-gravity, .mc_gravity, .mc-newsletter, .mc_newsletter classes
	 */
	function gform_confirmation( $confirmation, $form, $lead, $ajax ) {
		$form_css_classes = explode( ' ', $form['cssClass'] );

		// Confirmation message is set and form has one of our supported classes (alter the confirmation accordingly)
		if ( isset( $form['cssClass'] ) && $form['confirmation']['type'] === 'message' && in_array( $form_css_classes, array( 'mc-gravity', 'mc_gravity', 'mc-newsletter', 'mc_newsletter' ) ) )
			$confirmation = '<section class="mc-gravity-confirmation mc_gravity-confirmation mc-newsletter-confirmation mc_newsletter-confirmation">' . $confirmation . '</section>';

		return $confirmation;
	}


	/**********************
	 * Internal Functions *
	 **********************/

	/**
	 * This function sorts an array of $post objects by post date in descending order.
	 */
	function sort_post_date_desc( $a, $b ) {
		return strnatcmp( strtotime( $b->post_date ), strtotime( $a->post_date ) );
	}
}


function CaptureInstance() {
	return Capture::instance();
}

// Starts Capture
CaptureInstance();