/**
 * Capture Slideshow - A jQuery plugin for fullscreen slideshow functionality in the Capture WordPress theme.
 *
 * License: GPL2
 * Copyright Scott Sousa (Slocum Studio), http://slocumthemes.com/
 */

( function( $ ) {
	'use strict';

	// Global vars
	var $window = $( window ), timers = [], capture_options = { current: false, previous: false }, Image, Images, ImageCollection, CaptureSlideshowRouter, CaptureSlideshowRoutes, ImageView, CaptureImageView, pushState, isiPhone;

	$( function( ) {
		// Make sure Capture Slideshow element exists
		if ( $( '#capture-slideshow-template' ).length ) {
			// Define an Image Model
			Image = Backbone.Model.extend( {
				defaults: {
					// Image properties
					img: {
						src: false,
						width: false,
						height: false
					},
					// Post Properties
					post: {
						id: false,
						title: false,
						date: false,
						permalink: false
					}
				}
			} );


			// Define an Images Collection
			Images = Backbone.Collection.extend( {
				model: Image,
				url: capture.ajaxurl,
				initialize: function ( options ) {
					this.options = options || {}; // Store options

					_.bindAll( this, 'getModel', 'setModel', 'nextModel', 'prevModel' ); // Bind "this" to all functions
				},
				comparator: function( model ) {
					return model.get( 'id' );
				},
				getModel: function() {
					return this.currentModel;
				},
				setModel: function( model ) {
					if ( this.currentModel ) {
						this.currentModel.unset( 'current_image' ); // Remove current image flag
					}
					this.currentModel = model; // Set current model
					this.currentModel.set( { current_image: true } ); // Set current image flag
				},
				nextModel: function() {
					this.setModel( this.at( this.indexOf( this.getModel() ) + 1 ) );

					return this;
				},
				prevModel: function() {
					this.setModel( this.at( this.indexOf( this.getModel() ) - 1 ) );

					return this;
				}
			} );

			// Instantiate the new collection
			ImageCollection = new Images();


			// Define an ImageView View
			ImageView = Backbone.View.extend( {
				el: '#capture-slideshow .capture-slideshow',
				capture_slideshow_elements: {},
				template: _.template( $( '#capture-slideshow-template' ).html() ),
				initialize: function( options ) {
					this.options = options || {}; // Store options

					_.bindAll( this, 'render', 'getImages' ); // Bind "this" to all functions

					// Initialize Capture Slideshow Elements
					this.capture_slideshow_elements.$parent = this.$el.parent();
					this.capture_slideshow_elements.$img = $( '.capture-slideshow-photo img', this.$el );
					this.capture_slideshow_elements.$img_parent = this.capture_slideshow_elements.$img.parent();
					this.capture_slideshow_elements.$close = $( '.capture-slideshow-close', this.capture_slideshow_elements.$parent );
					this.capture_slideshow_elements.$prev = $( '.capture-slideshow-prev', this.capture_slideshow_elements.$parent );
					this.capture_slideshow_elements.$next = $( '.capture-slideshow-next', this.capture_slideshow_elements.$parent );
					this.capture_slideshow_elements.$ui_elements = $( '.capture-slideshow-ui', this.capture_slideshow_elements.$parent );
					this.capture_slideshow_elements.$loader = $( '.loader-container', this.capture_slideshow_elements.$parent );
				},
				render: function() {
					var _this = this; // Cache "this"

					// If we have images
					if ( this.collection.length ) {
						this.$el.html( this.template( this.collection.getModel().attributes ) );

						// Cache various Capture Slideshow elements
						this.capture_slideshow_elements.$parent = this.$el.parent();
						this.capture_slideshow_elements.$img = $( '.capture-slideshow-photo img', this.$el );
						this.capture_slideshow_elements.$img_parent = this.capture_slideshow_elements.$img.parent();
						this.capture_slideshow_elements.$prev = $( '.capture-slideshow-prev', this.capture_slideshow_elements.$parent );
						this.capture_slideshow_elements.$next = $( '.capture-slideshow-next', this.capture_slideshow_elements.$parent );
						this.capture_slideshow_elements.$ui_elements = $( '.capture-slideshow-ui', this.capture_slideshow_elements.$parent );
						this.capture_slideshow_elements.$loader = $( '.loader-container', this.capture_slideshow_elements.$parent );
						_this = this; // Reset "this" reference (now that we've changed the elements above)

						this.capture_slideshow_elements.$loader.removeClass( 'hidden hide' ); // Show the loader

						// Once all images are done loading
						this.$el.imagesLoaded().done( function() {
							_this.capture_slideshow_elements.$parent.addClass( 'loaded' ); // Slideshow container
							_this.capture_slideshow_elements.$ui_elements.removeClass( 'hidden hide initial-hide' );
							_this.capture_slideshow_elements.$loader.addClass( 'hidden hide' );

							// Previous & Next Buttons
							if ( _this.collection.getModel().attributes.hasOwnProperty( 'no_more_images' ) ) {
								if ( _this.collection.indexOf( _this.collection.getModel() ) === 0 ) {
									_this.capture_slideshow_elements.$prev.addClass( 'disabled' );
								}
								if ( _this.collection.indexOf( _this.collection.getModel() ) === ( _this.collection.length - 1 ) ) {
									_this.capture_slideshow_elements.$next.addClass( 'disabled' );
								}
							}

							// Image
							_this.capture_slideshow_elements.$img.fadeIn( 400, function() {
								$( this ).addClass( 'loaded' );
							} );

							// If only lightbox, we need to allow for fullscreen request
							if ( _this.options.hasOwnProperty( 'lightbox' ) && _this.options.lightbox ) {
								_this.capture_slideshow_elements.$img_parent.addClass( 'lightbox' );
								_this.capture_slideshow_elements.$img.on( 'click.capture-slideshow', function( e ) {
									e.preventDefault();

									openCaptureSlideshow();
								} );
							}

							// On swipe events - Hammer
							if ( capture.is_mobile ) {
								if( _this.capture_slideshow_elements.$img.data( 'capture-slideshow' ) !== 'active' ) {
									// Left (Next)
									Hammer( _this.capture_slideshow_elements.$img[0] ).on( 'dragleft swipeleft', function( e ) {
										//e.preventDefault();
										//e.gesture.preventDefault();

										_this.capture_slideshow_elements.$next.click();
									} );

									// Right(Prev)
									Hammer( _this.capture_slideshow_elements.$img[0] ).on( 'dragright swiperight', function( e ) {
										//e.preventDefault();
										//e.gesture.preventDefault();

										_this.capture_slideshow_elements.$prev.click();
									} );

									_this.capture_slideshow_elements.$img.data( 'capture-slideshow', 'active' );
								}
							}

							centerInWindow( _this.capture_slideshow_elements.$img ); // Initial element centering

							$( window ).on( 'resize.capture-slideshow', function() {
								clearTimeout( timers['window-resize'] );
								timers['window-resize'] = setTimeout( function() { centerInWindow( _this.capture_slideshow_elements.$img ); }, 100 );
							} );
						} );
					}

					return this;
				},
				// Fetch image models from server through the view's collection
				getImages: function( num_posts, callback ) {
					var _this = this;

					this.collection.fetch( { 
						data: {
							action: ( ! _this.options.gallery ) ? 'capture_slideshow' : 'capture_slideshow_gallery',
							nonce: capture.nonce,
							current_post_id: ( ! _this.options.gallery ) ? $( '.capture-slideshow-current-post-id', _this.$el ).val() : _this.options.gallery.post_id,
							initial_post_id: ( ! _this.options.gallery ) ? $( '.post', '.content-wrapper' ).attr( 'id' ).replace( 'post-', '' ) : false,
							num_next_prev_posts: ( ! _this.options.gallery ) ? num_posts : false,
							// Gallery
							gallery_id: ( _this.options.hasOwnProperty( 'gallery' ) ) ? _this.options.gallery.id : false,
							gallery_image_id: ( _this.options.hasOwnProperty( 'gallery' ) ) ? _this.options.gallery.image_id : false,
						},
						success: function( collection, response ) {
							// Find and set current model
							_.each( collection.models, function( model ) {
								if ( model.attributes.hasOwnProperty( 'current_image' ) ) {
									collection.setModel( model );
								}
							} );

							// Run the callback function
							callback( collection, response );
						},
						error:  function( collection, response ) {
							closeCaptureSlideshow(); // Close the slideshow
							alert( 'Capture Slideshow: There was an error fetching models from the server. Please try again.' );
						}
					} );
				}
			} );

			// Define a Router
			CaptureSlideshowRouter = Backbone.Router.extend( {
				prev_url_path: false,
				routes: {
					'*notFound': 'defaultRoute',
					'': 'defaultRoute'
				},
				defaultRoute: function( path ) {
					// Determine if user has clicked the back/forward buttons
					// In the future we'll use backbone to actually navigate in this case
					if ( pushState && this.prev_url_path && path !== this.prev_url_path ) {
						window.location.reload();
					}

					this.prev_url_path = path;
				}
			} );

			CaptureSlideshowRoutes = new CaptureSlideshowRouter();

			// Start the History API/Route handler
			pushState = !! ( window.history && window.history.pushState ); // Check to disable pushState for older browsers (bool)

			Backbone.history.start( { pushState: pushState, root: '' } );

			// Determine if user is on an iPhone
			isiPhone = ( navigator.userAgent.match( /iPhone/i ) ) ? true : false;
		}
	} );


	/**
	 * Capture Slideshow Plugin
	 */
	$.fn.captureSlideshow = function( options ) {
		var $document = $( document ), opts = $.extend( {}, $.fn.captureSlideshow.defaults, options ), opts_diff_flag = false, path = ( capture.permalinks ) ? window.location.pathname : window.location.pathname + window.location.search, $gallery_thumbs, $gallery_thumbs_children, $gallery_thumbs_list;

		// Store the option data
		capture_options.current = opts;

		if ( ! capture_options.previous ) {
			capture_options.previous = opts;
		}

		// Determine if the same gallery is being loaded
		if ( CaptureImageView instanceof Backbone.View && ( ( capture.is_archive && capture_options.previous.current_post_id === opts.current_post_id ) || ( ! capture.is_archive && capture_options.previous.hasOwnProperty( 'gallery' ) && opts.hasOwnProperty( 'gallery' ) ) ) ) {
			// Find and set current model
			_.each( CaptureImageView.collection.models, function( model ) {
				if ( model.attributes.img.id === opts.gallery_image_id ) {
					CaptureImageView.collection.setModel( model );
					CaptureImageView.render();
				}
			} );

			$gallery_thumbs = $( '.capture-slideshow-thumbs .capture-slideshow-gallery-item', '#' + CaptureImageView.capture_slideshow_elements.$parent.attr( 'id' ) );
			$gallery_thumbs_children = $gallery_thumbs.children( '.gallery-icon' );
			$gallery_thumbs_list = $( '.capture-slideshow-thumbs', '#' + CaptureImageView.capture_slideshow_elements.$parent.attr( 'id' ) );

			// Set active thumbnail
			$gallery_thumbs_list.children( '.capture-slideshow-gallery-item' ).removeClass( 'active' );
			$gallery_thumbs_children.each( function() {
				if ( CaptureImageView.collection.getModel().attributes.img.id === parseInt( $( this ).attr( 'data-gallery-image-id' ), 10 ) ) {
					$( this ).parents( '.capture-slideshow-gallery-item' ).addClass( 'active' );
				}
			} );

			$gallery_thumbs_list.css( { bottom: ( isiPhone ) ? $gallery_thumbs_list.height() + 'px' : 0 } );
			CaptureImageView.$el.find( '.capture-slideshow-details' ).css( { bottom: ( isiPhone ) ? ( ( $gallery_thumbs_list.height() * 2 ) + 2 ) + 'px' : ( $gallery_thumbs_list.height() + 2 ) + 'px' } );
		}
		// If the previous options differ with the new options
		else if ( capture_options.previous && ! _.isEqual( capture_options.previous, capture_options.current ) ) {
			ImageCollection = new Images(); // Instantiate a new collection

			opts_diff_flag = true; // Set the flag
			capture_options.previous = opts;
		}

		// New CaptureImageView
		if( ! ( CaptureImageView instanceof Backbone.View ) || opts_diff_flag ) {
			CaptureImageView = new ImageView( {
				collection: ImageCollection,
				lightbox: ( opts.hasOwnProperty( 'lightbox' ) && opts.lightbox ) ? true : false,
				gallery: ( opts.hasOwnProperty( 'gallery' ) && opts.gallery ) ? {
					id: opts.gallery_id,
					image_id: opts.gallery_image_id,
					post_id: opts.current_post_id
				} : false
			} );
		}

		// Fetch initial data and render the view based on that data
		if ( CaptureImageView.collection.length === 0 || ( capture.is_archive && opts_diff_flag ) ) {
			CaptureImageView.capture_slideshow_elements.$ui_elements.addClass( 'hidden hide initial-hide' ); // Initial hide

			// Determine if the previous image should be hidden on load
			if ( opts_diff_flag ) {
				CaptureImageView.capture_slideshow_elements.$loader.removeClass( 'hidden hide' );
				CaptureImageView.capture_slideshow_elements.$img_parent.html( '' );
				CaptureImageView.$el.find( '.capture-slideshow-details' ).html( '' );
			}

			// Fetch images from server
			CaptureImageView.getImages( 2, function( collection, response ) {
				CaptureImageView.render();

				// If we're loading a gallery, make sure to append the thumbnails and functionality
				if ( opts.hasOwnProperty( 'gallery' ) && opts.gallery && ( ( capture.is_archive && capture_options.previous.current_post_id === opts.current_post_id ) || ! $( '.capture-slideshow-thumbs', '#' + CaptureImageView.capture_slideshow_elements.$parent.attr( 'id' ) ).length ) ) {
					$gallery_thumbs = ( opts.hasOwnProperty( 'gallery_thumbs' ) && opts.gallery_thumbs ) ? opts.gallery_thumbs.clone() : $( '.gallery .capture-slideshow-gallery-item', '.' + CaptureImageView.capture_slideshow_elements.$parent.parent().attr( 'class' ) ).clone();
					$gallery_thumbs_children = $gallery_thumbs.children( '.gallery-icon' );

					// Ensure thumbnails are sized properly
					$gallery_thumbs.width( 100 / $gallery_thumbs.length + '%' );

					// Determine active image
					$gallery_thumbs.each( function() {
						if ( parseInt( $( this ).children( '.gallery-icon' ).attr( 'data-gallery-image-id' ), 10 ) === CaptureImageView.collection.getModel().attributes.img.id ) {
							$( this ).addClass( 'active' );
						}
					} );

					// If we're on an archive template, replace gallery thumbs to slideshow
					if ( capture.is_archive && $( '.capture-slideshow-thumbs', '#' + CaptureImageView.capture_slideshow_elements.$parent.attr( 'id' ) ).length ) {
						$( '.capture-slideshow-thumbs', '#' + CaptureImageView.capture_slideshow_elements.$parent.attr( 'id' ) ).html( '' );
					}
					else {
						CaptureImageView.capture_slideshow_elements.$parent.append( '<section class="capture-slideshow-thumbs capture-slideshow-ui" />' );
					}

					$( '.capture-slideshow-thumbs', '#' + CaptureImageView.capture_slideshow_elements.$parent.attr( 'id' ) ).append( $gallery_thumbs );
					$gallery_thumbs_list = $( '.capture-slideshow-thumbs', '#' + CaptureImageView.capture_slideshow_elements.$parent.attr( 'id' ) );

					// Reset UI Elements (include gallery thumbs)
					CaptureImageView.capture_slideshow_elements.$ui_elements = $( '.capture-slideshow-ui', CaptureImageView.capture_slideshow_elements.$parent );

					// Gallery thumbnail functionality
					$gallery_thumbs_children.on( 'click.capture-slideshow', function( e ) {
						var $this = $( this ), clicks;

						e.preventDefault();

						clicks = parseInt( $gallery_thumbs_list.data( 'capture-slideshow.clicks' ), 10 ) || 0;
						clicks++;

						// Store total number of clicks
						$gallery_thumbs_list.data( 'capture-slideshow.clicks', clicks );

						// Make sure this gallery item isn't already active
						if ( ! $( this ).parent().hasClass( 'active' ) ) {
							$gallery_thumbs_list.children( '.capture-slideshow-gallery-item' ).removeClass( 'active' );
							$( this ).parent().addClass( 'active' );

							// Loop through models, determine which should be active, and render it
							_.each( CaptureImageView.collection.models, function( model ) {
								if ( model.attributes.img.id === parseInt( $this.attr( 'data-gallery-image-id' ), 10 ) ) {
									CaptureImageView.collection.setModel( model );
									CaptureImageView.render();
								}
							} );

							// Remove post details on mobile
							if ( capture.is_mobile && clicks >= 1 ) {
								CaptureImageView.$el.find( '.capture-slideshow-details' ).hide();
							}

							$gallery_thumbs_list.css( { bottom: ( isiPhone ) ? $gallery_thumbs_list.height() + 'px' : 0 } );
							CaptureImageView.$el.find( '.capture-slideshow-details' ).css( { bottom: ( isiPhone ) ? ( ( $gallery_thumbs_list.height() * 2 ) + 2 ) + 'px' : ( $gallery_thumbs_list.height() + 2 ) + 'px' } );
						}
						else {
							return false;
						}
					} );

					// Ensure slideshow details line up with thumbnails
					$gallery_thumbs_list.css( { bottom: ( isiPhone ) ? $gallery_thumbs_list.height() + 'px' : 0 } );
					CaptureImageView.$el.find( '.capture-slideshow-details' ).css( { bottom: ( isiPhone ) ? ( ( $gallery_thumbs_list.height() * 2 ) + 2 ) + 'px' : ( $gallery_thumbs_list.height() + 2 ) + 'px' } );
					$( window ).on( 'resize.capture-slideshow', function() {
						$gallery_thumbs_list.css( { bottom: ( isiPhone ) ? $gallery_thumbs_list.height() + 'px' : 0 } );
						CaptureImageView.$el.find( '.capture-slideshow-details' ).css( { bottom: ( isiPhone ) ? ( ( $gallery_thumbs_list.height() * 2 ) + 2 ) + 'px' : ( $gallery_thumbs_list.height() + 2 ) + 'px' } );
					} );
				}
				else if ( ( ! opts.hasOwnProperty( 'gallery' ) || ! opts.gallery ) && $( '.capture-slideshow-thumbs', '#' + CaptureImageView.capture_slideshow_elements.$parent.attr( 'id' ) ).length ) {
					$( '.capture-slideshow-thumbs', '#' + CaptureImageView.capture_slideshow_elements.$parent.attr( 'id' ) ).remove();
				}
			} );
		}

		// Trim trailing slash off of URL
		if ( path.substr( -1 ) === '/' ) {
			path = ( pushState ) ? path.substr( 0, path.length - 1 ) : window.location.hash.substr( 0, window.location.hash.length - 1 );
		}
		// Set path to window hash (no pushState)
		else if ( ! pushState ) {
			path = window.location.hash;
		}

		// Featured Image Slideshow
		if ( ! opts.hasOwnProperty( 'gallery' ) ) {
			// Navigate to current URL + /lightbox/ (pushState)
			if ( pushState && ( ( capture.permalinks && path.split( '/' ).pop() !== 'lightbox' ) || ( ! capture.permalinks && path.indexOf( '&lightbox=true' ) === -1 ) ) ) {
				CaptureSlideshowRoutes.navigate( ( capture.permalinks ) ? path + '/lightbox/': path + '&lightbox=true', { replace: true } );
			}
			// No pushState
			else if ( ( capture.permalinks && path === '#lightbox' ) || ( ! capture.permalinks && path.indexOf( '&lightbox=true' ) === -1 ) ) {
				CaptureSlideshowRoutes.navigate( ( capture.permalinks ) ? '/lightbox': '&lightbox=true', { replace: true } );
			}
		}

		// Request fullscreen access (start the slideshow)
		openCaptureSlideshow();

		// Bind all events
		if ( CaptureImageView.capture_slideshow_elements.$parent.data( 'capture-slideshow' ) !== 'active' ) {
			// On document keyup
			$document.on( 'keyup.capture-slideshow', function( e ) {
				// Esc - close slideshow
				if ( e.keyCode === 27 ) {
					closeCaptureSlideshow();
				}

				// Left Arrow - advance to prev image
				if ( e.keyCode === 37 ) {
					CaptureImageView.capture_slideshow_elements.$prev.click();
				}

				// Right Arrow - advance to next image
				if ( e.keyCode === 39 ) {
					CaptureImageView.capture_slideshow_elements.$next.click();
				}
			} );

			// On fullscreen event
			$document.on( 'webkitfullscreenchange mozfullscreenchange fullscreenchange', function( e ) { // Fullscreen change
				var has_fullscreen = document.fullscreen || document.mozFullScreen || document.webkitIsFullScreen || false;

				if ( ! has_fullscreen ) {
					closeCaptureSlideshow();
				}
			} );

			// On close button click cancel fullscreen access
			CaptureImageView.capture_slideshow_elements.$close.on( 'click.capture-slideshow', function( e ) {
				e.preventDefault();

				closeCaptureSlideshow();
			} );

			// Next/Previous Buttons
			CaptureImageView.capture_slideshow_elements.$prev.on( 'click.capture-slideshow', function( e ) {
				var _this = $( this ), clicks, num_posts;

				e.preventDefault();

				// If button is disabled, return
				if ( $( this ).hasClass( 'disabled' ) ) {
					return false;
				}

				// Store total number of clicks
				if ( ! opts.hasOwnProperty( 'gallery' ) || ! opts.gallery ) {
					clicks = parseInt( $( this ).data( 'capture-slideshow.clicks' ), 10 ) || 0;
					clicks++;
					num_posts = ( clicks > 2 ) ? 5 : 2; // Set number of posts to fetch (on both sides of current post)
					$( this ).data( 'capture-slideshow.clicks', clicks );
				}
				else {
					clicks = parseInt( $gallery_thumbs_list.data( 'capture-slideshow.clicks' ), 10 ) || 0;
					clicks++;
					$gallery_thumbs_list.data( 'capture-slideshow.clicks', clicks );
				}

				// Enable next button
				CaptureImageView.capture_slideshow_elements.$next.removeClass( 'disabled' );

				// Featured Image Slideshow
				if ( ! opts.hasOwnProperty( 'gallery' ) || ! opts.gallery ) {
					// Render previous image in collection
					if ( CaptureImageView.collection.indexOf( CaptureImageView.collection.getModel() ) !== 0 ) {
						CaptureImageView.collection.prevModel();
						CaptureImageView.capture_slideshow_elements.$img.removeClass( 'loaded' ).fadeOut( 400, function() {
							CaptureImageView.render();
						} );

						// If we have no more previous images and we're at the last one disable the button
						if ( CaptureImageView.collection.getModel().attributes.hasOwnProperty( 'no_more_images' ) ) {
							$( this ).addClass( 'disabled' );
						}
					}
					// Fetch new images for collection
					else {
						CaptureImageView.capture_slideshow_elements.$ui_elements.addClass( 'hidden hide initial-hide' );
						CaptureImageView.capture_slideshow_elements.$loader.removeClass( 'hidden hide' );

						CaptureImageView.capture_slideshow_elements.$img.removeClass( 'loaded' ).fadeOut( 400, function() {

							CaptureImageView.getImages( num_posts, function( collection, response ) {
								if ( CaptureImageView.collection.indexOf( CaptureImageView.collection.getModel() ) !== 0 ) {
									CaptureImageView.collection.prevModel(); // Switch to previous model
									CaptureImageView.render();

									// If we have no more next images and we're at the last one disable the button
									if ( CaptureImageView.collection.getModel().attributes.hasOwnProperty( 'no_more_images' ) ) {
										_this.addClass( 'disabled' );
									}
								}
							} );
						} );
					}
				}
				// Gallery Slideshow
				else {
					// Fetch previous image in collection
					if ( CaptureImageView.collection.indexOf( CaptureImageView.collection.getModel() ) !== 0 ) {
						CaptureImageView.collection.prevModel();
					}
					// Fetch last image in collection
					else {
						CaptureImageView.collection.setModel( CaptureImageView.collection.at( CaptureImageView.collection.length - 1 ) );
					}

					// Render image
					CaptureImageView.capture_slideshow_elements.$img.removeClass( 'loaded' ).fadeOut( 400, function() {
						CaptureImageView.render();
						$gallery_thumbs_list.css( { bottom: ( isiPhone ) ? $gallery_thumbs_list.height() + 'px' : 0 } );
						CaptureImageView.$el.find( '.capture-slideshow-details' ).css( { bottom: ( isiPhone ) ? ( ( $gallery_thumbs_list.height() * 2 ) + 2 ) + 'px' : ( $gallery_thumbs_list.height() + 2 ) + 'px' } );

						// Remove post details on mobile
						if ( capture.is_mobile && clicks >= 1 ) {
							CaptureImageView.$el.find( '.capture-slideshow-details' ).hide();
						}
					} );

					// Gallery Thumbnails
					$gallery_thumbs_list.children( '.capture-slideshow-gallery-item' ).removeClass( 'active' );
					$gallery_thumbs_children.each( function() {
						if ( CaptureImageView.collection.getModel().attributes.img.id === parseInt( $( this ).attr( 'data-gallery-image-id' ), 10 ) ) {
							$( this ).parents( '.capture-slideshow-gallery-item' ).addClass( 'active' );
						}
					} );
				}
			} );

			CaptureImageView.capture_slideshow_elements.$next.on( 'click.capture-slideshow', function( e ) {
				var _this = $( this ), clicks, num_posts;

				e.preventDefault();

				// If button is disabled, return
				if ( $( this ).hasClass( 'disabled' ) ) {
					return false;
				}

				// Store total number of clicks
				if ( ! opts.hasOwnProperty( 'gallery' ) || ! opts.gallery ) {
					clicks = parseInt( $( this ).data( 'capture-slideshow.clicks' ), 10 ) || 0;
					clicks++;
					num_posts = ( clicks > 2 ) ? 5 : 2; // Set number of posts to fetch (on both sides of current post)
					$( this ).data( 'capture-slideshow.clicks', clicks );
				}
				else {
					clicks = parseInt( $gallery_thumbs_list.data( 'capture-slideshow.clicks' ), 10 ) || 0;
					clicks++;
					$gallery_thumbs_list.data( 'capture-slideshow.clicks', clicks );
				}

				// Enable previous button
				CaptureImageView.capture_slideshow_elements.$prev.removeClass( 'disabled' );

				// Featured Image Slideshow
				if ( ! opts.hasOwnProperty( 'gallery' ) || ! opts.gallery ) {
					// Render next image in collection
					if ( CaptureImageView.collection.indexOf( CaptureImageView.collection.getModel() ) !== ( CaptureImageView.collection.length - 1 ) ) {
						CaptureImageView.collection.nextModel();
						CaptureImageView.capture_slideshow_elements.$img.removeClass( 'loaded' ).fadeOut( 400, function() {
							CaptureImageView.render();
						} );

						// If we have no more previous images and we're at the last one disable the button
						if ( CaptureImageView.collection.getModel().attributes.hasOwnProperty( 'no_more_images' ) ) {
							$( this ).addClass( 'disabled' );
						}
					}
					// Fetch new images for collection
					else {
						CaptureImageView.capture_slideshow_elements.$ui_elements.addClass( 'hidden hide initial-hide' );
						CaptureImageView.capture_slideshow_elements.$loader.removeClass( 'hidden hide' );

						CaptureImageView.capture_slideshow_elements.$img.removeClass( 'loaded' ).fadeOut( 400, function() {

							CaptureImageView.getImages( num_posts, function( collection, response ) {
								if ( CaptureImageView.collection.indexOf( CaptureImageView.collection.getModel() ) !== 0 ) {
									CaptureImageView.collection.nextModel(); // Switch to previous model
									CaptureImageView.render();

									// If we have no more next images and we're at the last one disable the button
									if ( CaptureImageView.collection.getModel().attributes.hasOwnProperty( 'no_more_images' ) ) {
										_this.addClass( 'disabled' );
									}
								}
							} );
						} );
					}
				}
				// Gallery Slideshow
				else {
					// Fetch previous image in collection
					if ( CaptureImageView.collection.indexOf( CaptureImageView.collection.getModel() ) !== ( CaptureImageView.collection.length - 1 ) ) {
						CaptureImageView.collection.nextModel();
					}
					// Fetch first image in collection
					else {
						CaptureImageView.collection.setModel( CaptureImageView.collection.at( 0 ) );
					}

					// Render image
					CaptureImageView.capture_slideshow_elements.$img.removeClass( 'loaded' ).fadeOut( 400, function() {
						CaptureImageView.render();
						$gallery_thumbs_list.css( { bottom: ( isiPhone ) ? $gallery_thumbs_list.height() + 'px' : 0 } );
						CaptureImageView.$el.find( '.capture-slideshow-details' ).css( { bottom: ( isiPhone ) ? ( ( $gallery_thumbs_list.height() * 2 ) + 2 ) + 'px' : ( $gallery_thumbs_list.height() + 2 ) + 'px' } );

						// Remove post details on mobile
						if ( capture.is_mobile && clicks >= 1 ) {
							CaptureImageView.$el.find( '.capture-slideshow-details' ).hide();
						}
					} );

					// Gallery Thumbnails
					$gallery_thumbs_list.children( '.capture-slideshow-gallery-item' ).removeClass( 'active' );
					$gallery_thumbs_children.each( function() {
						if ( CaptureImageView.collection.getModel().attributes.img.id === parseInt( $( this ).attr( 'data-gallery-image-id' ), 10 ) ) {
							$( this ).parents( '.capture-slideshow-gallery-item' ).addClass( 'active' );
						}
					} );
				}
			} );


			// Post Details
			CaptureImageView.capture_slideshow_elements.$parent.on( 'mousemove.capture-slideshow', function() {
				// Make sure we have UI Elements loaded
				if ( ! CaptureImageView.capture_slideshow_elements.$ui_elements ) {
					return false;
				}

				// If we're not on the initial hide
				if ( ! CaptureImageView.capture_slideshow_elements.$ui_elements.hasClass( 'initial-hide' ) && ! capture.is_mobile ) {
					CaptureImageView.capture_slideshow_elements.$ui_elements.removeClass( 'hidden hide' ); // Unhide UI elements
					clearTimeout( timers['capture-slideshow-mousemove'] );
					timers['capture-slideshow-mousemove'] = setTimeout( function() { 
						CaptureImageView.capture_slideshow_elements.$ui_elements.addClass( 'hidden hide' );
					}, 2500 );
				}
			} );

			// Set capture slideshow data
			CaptureImageView.capture_slideshow_elements.$parent.data( 'capture-slideshow', 'active' );
		}

		return this;
	};

	// Default options
	$.fn.captureSlideshow.defaults = {
	};


	/********************
	 * Helper Functions *
	 ********************/

	/**
	 * This function centers an element within the window.
	 */
	function centerInWindow( element ) {
		var img, wind;
		img = { orig_height: parseInt( element.attr( 'height' ), 10 ), orig_width: parseInt( element.attr( 'width' ), 10 ), smaller_than_window: false };
		img.aspect_ratio = img.orig_width / img.orig_height;
		img.aspect_ratio = img.aspect_ratio.toFixed( 2 ); // Trim to 2 decimal points
		wind = { aspect_ratio: $window.width() / $window.height() };
		wind.aspect_ratio = wind.aspect_ratio.toFixed( 2 ); // Trim to 2 decimal points

		// Check to see if the window width/height are larger than the original image
		if ( $window.width() > img.orig_width && $window.height() > img.orig_height ) {
			element.css( {
				position: 'absolute',
				top: ( ( $window.height() - element.height() ) / 2 ) + 'px',
				left: ( ( $window.width() - element.width() ) / 2 ) + 'px',
				width: 'auto',
				height: 'auto'
			} );

			// Set flag for image being smaller than window
			img.smaller_than_window = true;
		}

		// Check to see if window width/height aspect ratio are the same ratio as original image
		if ( wind.aspect_ratio === img.aspect_ratio && ! img.smaller_than_window ) {
			element.css( {
				width: $window.width(),
				height: $window.height(),
				top: 0,
				left: 0
			} );
		}

		// Check to see if window width/height aspect ratio is larger than original image (window width larger than height)
		if ( wind.aspect_ratio > img.aspect_ratio && ! img.smaller_than_window ) {
			element.css( {
				width: 'auto',
				height: $window.height(),
				top: 0,
				left: ( ( $window.width() - ( $window.height() * img.aspect_ratio ) ) / 2 ) + 'px'
			} );
		}

		// Check to see if window width/height aspect ratio is smaller than original image (window height larger than width)
		if ( wind.aspect_ratio < img.aspect_ratio && ! img.smaller_than_window ) {
			element.css( {
				width: $window.width(),
				height: ( $window.width() / img.aspect_ratio ),
				top: ( ( $window.height() - ( $window.width() / img.aspect_ratio ) ) / 2 ) + 'px',
				left: 0
			} );
		}
			
		return element;
	}

	/**
	 * This function requests fullscreen via the HTML5 Fullscreen API (if available).
	 */
	function openCaptureSlideshow() {
		var $body = $( 'body' );

		// Exit if an element already has fullscreen access
		if ( document.fullscreenElement || document.mozFullScreenElement || document.webkitFullscreenElement || document.msFullscreenElement ) {
			return false;
		}

		// W3C
		if ( CaptureImageView.capture_slideshow_elements.$parent[0].requestFullScreen ) {
			CaptureImageView.capture_slideshow_elements.$parent[0].requestFullScreen();
			CaptureImageView.capture_slideshow_elements.$parent.addClass( 'capture-slideshow-full capture-slideshow-fullscreen capture-slideshow-full-w3c capture-slideshow-fullscreen-w3c full-screen-w3c fullscreen-w3c' );
		}
		// Mozilla
		else if ( CaptureImageView.capture_slideshow_elements.$parent[0].mozRequestFullScreen ) {
			CaptureImageView.capture_slideshow_elements.$parent[0].mozRequestFullScreen();
			CaptureImageView.capture_slideshow_elements.$parent.addClass( 'capture-slideshow-full capture-slideshow-fullscreen capture-slideshow-full-moz capture-slideshow-fullscreen-moz full-screen-moz fullscreen-moz' );
		}
		// Webkit
		else if ( CaptureImageView.capture_slideshow_elements.$parent[0].webkitRequestFullScreen ) {
			CaptureImageView.capture_slideshow_elements.$parent[0].webkitRequestFullScreen();
			CaptureImageView.capture_slideshow_elements.$parent.addClass( 'capture-slideshow-container capture-slideshow-full capture-slideshow-fullscreen capture-slideshow-full-webkit capture-slideshow-fullscreen-webkit full-screen-webkit fullscreen-webkit' );
		}
		// MS
		else if ( CaptureImageView.capture_slideshow_elements.$parent[0].msRequestFullScreen ) {
			CaptureImageView.capture_slideshow_elements.$parent[0].msRequestFullScreen();
			CaptureImageView.capture_slideshow_elements.$parent.addClass( 'capture-slideshow-container capture-slideshow-full capture-slideshow-fullscreen capture-slideshow-full-ms capture-slideshow-fullscreen-ms full-screen-ms fullscreen-ms' );
		}
		// All other browsers/devices
		else {
			CaptureImageView.capture_slideshow_elements.$parent.addClass( 'capture-slideshow-full capture-slideshow-fullscreen capture-slideshow-no-fullscreen-api' );
		}

		$body.addClass( ( capture_options.current.hasOwnProperty( 'gallery' ) && capture_options.current.gallery ) ? 'capture-slideshow-active lightbox capture-slideshow-gallery gallery' : 'capture-slideshow-active lightbox' );

		return CaptureImageView.capture_slideshow_elements.$parent;
	}

	/**
	 * This function cancels fullscreen via the HTML5 Fullscreen API (if available) and also any Capture Slideshow functionality.
	 */
	function closeCaptureSlideshow() {
		var $body = $( 'body' ), path = ( capture.permalinks ) ? window.location.pathname : window.location.pathname + window.location.search;

		// Remove events and set slideshow flag to inactive
		CaptureImageView.capture_slideshow_elements.$parent.data( 'capture-slideshow', 'inactive' );
		CaptureImageView.capture_slideshow_elements.$parent.off( 'mousemove.capture-slideshow' );
		CaptureImageView.capture_slideshow_elements.$close.off( 'click.capture-slideshow' );
		CaptureImageView.capture_slideshow_elements.$prev.off( 'click.capture-slideshow' );
		CaptureImageView.capture_slideshow_elements.$next.off( 'click.capture-slideshow' );
		$( document ).off( 'keyup.capture-slideshow webkitfullscreenchange mozfullscreenchange fullscreenchange' );

		// Trim trailing slash off of URL
		if ( ( pushState && path.substr( -1 ) === '/' ) || window.location.hash.substr( -1 ) === '/' ) {
			path = ( pushState ) ? path.substr( 0, path.length - 1 ) : window.location.hash.substr( 0, window.location.hash.length - 1 );
		}
		// Set path to window hash (no pushState)
		else if ( ! pushState ) {
			path = window.location.hash;
		}

		// Featured Image Slideshow
		if ( ! capture_options.current.hasOwnProperty( 'gallery' ) || ! capture_options.current.gallery ) {
			// Navigate to current URL without "lightbox" (pushState)
			if ( pushState && ( ( capture.permalinks && path.split( '/' ).pop() === 'lightbox' ) || ( ! capture.permalinks && path.indexOf( '&lightbox=true' ) !== -1 ) ) ) {
				CaptureSlideshowRoutes.navigate( ( capture.permalinks ) ? path.replace( 'lightbox', '' ) : path.replace( '&lightbox=true', '' ), { replace: true } );
			}
			// No pushState
			else if ( ( capture.permalinks && path === '#lightbox' ) || ( ! capture.permalinks && path.indexOf( '&lightbox=true' ) !== -1 ) ) {
				CaptureSlideshowRoutes.navigate( ( capture.permalinks ) ? '/' : window.location.hash.replace( '&lightbox=true', '' ), { replace: true } );
			}

			// Check to see if we've navigated away from the current post
			if ( pushState && CaptureImageView.collection.length && ! CaptureImageView.collection.getModel().attributes.hasOwnProperty( 'initial_image' ) ) {
				// Make sure we have UI Elements loaded
				if ( CaptureImageView.capture_slideshow_elements.$ui_elements ) {
					CaptureImageView.capture_slideshow_elements.$img.removeClass( 'loaded' ).fadeOut( 400, function() {
						CaptureImageView.capture_slideshow_elements.$ui_elements.addClass( 'hidden hide initial-hide' );
						CaptureImageView.capture_slideshow_elements.$loader.removeClass( 'hidden hide' );

						// Backbone navigate to post
							CaptureSlideshowRoutes.navigate( CaptureImageView.collection.getModel().attributes.post.permalink, { trigger: true } );
							window.location.reload( CaptureImageView.collection.getModel().attributes.post.permalink ); // Force a reload of current location to ensure new post is loaded
					} );
				}
			}
			else {
				CaptureImageView.capture_slideshow_elements.$parent.attr( 'class', 'capture-slideshow-container' );
				$body.removeClass( 'capture-slideshow-active lightbox' );
			}
		}
		// Gallery Slideshow
		else {
			CaptureImageView.capture_slideshow_elements.$parent.attr( 'class', 'capture-slideshow-container' );
			$body.removeClass( 'capture-slideshow-active lightbox capture-slideshow-gallery gallery' );
		}

		// W3C
		if ( document.cancelFullScreen ) {
			document.cancelFullScreen();
		}
		// Mozilla
		else if ( document.mozCancelFullScreen ) {
			document.mozCancelFullScreen();
		}
		// Webkit
		else if ( document.webkitCancelFullScreen ) {
			document.webkitCancelFullScreen();
		}
		// MS
		else if ( document.msCancelFullScreen ) {
			document.msCancelFullScreen();
		}
	}
}( jQuery ) );